summaryrefslogtreecommitdiff
path: root/pjlib/include/pj/types.h
diff options
context:
space:
mode:
Diffstat (limited to 'pjlib/include/pj/types.h')
-rw-r--r--pjlib/include/pj/types.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/pjlib/include/pj/types.h b/pjlib/include/pj/types.h
index 420ddd9b..0e0e2d9a 100644
--- a/pjlib/include/pj/types.h
+++ b/pjlib/include/pj/types.h
@@ -86,15 +86,18 @@ typedef int pj_bool_t;
# define PJ_T(literal_str) literal_str
#endif
+/** Some constants */
+enum pj_constants_
+{
+ /** Status is OK. */
+ PJ_SUCCESS=0,
-/** Status is OK. */
-#define PJ_SUCCESS 0
-
-/** True value. */
-#define PJ_TRUE 1
+ /** True value. */
+ PJ_TRUE=1,
-/** False value. */
-#define PJ_FALSE 0
+ /** False value. */
+ PJ_FALSE=0
+};
/**
* File offset type.